#!/bin/bash

export PATH=/bin:/sbin:/usr/bin:/usr/sbin

if [ "x$2" == "x" ]; then
  echo go away
  exit -1
fi
if [ "x$3" != "x" ]; then
  echo go away
  exit -1
fi

export g_user="$1"
export g_uid="$2"

## Check to see if a line like what we want exists
grep :$g_user /etc/devzone/user_zones.txt | grep :$g_uid &> /dev/null
if [ $? != 0 ]; then
  exit -1
fi

## Get the name of the zone that goes with our user
export zone_name=`awk '/:'$g_user'.*':$g_uid'/ {sub(":"," ");print $1}' /etc/devzone/user_zones.txt`
if [ "x$zone_name" == "x" ]; then
  exit -1
fi

echo setting up zone: $zone_name

## Make sure zone does not currently exist
#  (if it does and it's configured/installed/running, then delete/remove/halt it)
zonecfg -z $zone_name export 2>&1 | grep -v 'No such zone configured' > /dev/null
if [ $? == 0 ]; then
  # Uh oh, zone exists?
  export ZONE_STATE=`zoneadm -z $zone_name list -p | cut -d: -f3`
  case "$ZONE_STATE" in
    running)
      echo halting old zone instance
      zoneadm -z $zone_name halt
      echo uninstalling old zone instance
      zoneadm -z $zone_name uninstall -F
      echo deleting old zone configuration
      zonecfg -z $zone_name delete -F
      ;;
    installed)
      echo uninstalling old zone instance
      zoneadm -z $zone_name uninstall -F
      echo deleting old zone configuration
      zonecfg -z $zone_name delete -F
      ;;
    configured)
      echo deleting old zone configuration
      zonecfg -z $zone_name delete -F
      ;;
    *)
      echo error: $zone_name is in $ZONE_STATE
      exit -1
      ;;
  esac
fi

CONFIG_TEMPLATE="/etc/devzone/templates/default"
if [ -r "/etc/devzone/templates/$zone_name" ]; then
  CONFIG_TEMPLATE="/etc/devzone/templates/$zone_name"
fi

if [ ! -r $CONFIG_TEMPLATE ]; then
  echo Error: no config template found for zone
  exit -1
fi

## Let's configure the zone.
awk '{sub("{USERNAME}", "'$g_user'");print;}' $CONFIG_TEMPLATE | zonecfg -z $zone_name -f -

if [ $? != 0 ]; then
  echo Error: something went wrong with zone configuration.
  exit -1
fi

## Now let's build the zone from a read-made base zone
#  Base zone name is hard coded to "base_zone"
zoneadm -z $zone_name clone base_zone

# exit status is carried from the zoneadm command
